==> cyphesis-0.5.6.tar.bz2: cyphesis-0.5.6/rulesets/TerrainProperty.h <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2004 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef RULESETS_TERRAIN_PROPERTY_H
#define RULESETS_TERRAIN_PROPERTY_H

#include "common/Property.h"

#include <set>

namespace Mercator {
    class Terrain;
}

typedef std::map<int, std::set<int> > PointSet;

/// \brief Class to handle Entity terrain property
class TerrainProperty : public PropertyBase {
  protected:
    Mercator::Terrain & m_data;
    PointSet & m_modifiedTerrain;
    PointSet & m_createdTerrain;
  public:
    explicit TerrainProperty(Mercator::Terrain & data,
                             PointSet & modifiedTerrain,
                             PointSet & createdTerrain,
                             unsigned int flags);

    virtual void get(Atlas::Message::Element &) const;
    virtual void set(const Atlas::Message::Element &);
};

#endif // RULESETS_TERRAIN_PROPERTY_H

==> cyphesis-0.5.8.tar.bz2: cyphesis-0.5.8/rulesets/TerrainProperty.h <==
// Cyphesis Online RPG Server and AI Engine
// Copyright (C) 2004 Alistair Riddoch
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA

#ifndef RULESETS_TERRAIN_PROPERTY_H
#define RULESETS_TERRAIN_PROPERTY_H

#include "common/Property.h"

#include <set>

namespace Mercator {
    class Terrain;
}

typedef std::map<int, std::set<int> > PointSet;

/// \brief Class to handle Entity terrain property
class TerrainProperty : public PropertyBase {
  protected:
    Mercator::Terrain & m_data;
    PointSet & m_modifiedTerrain;
    PointSet & m_createdTerrain;
  public:
    explicit TerrainProperty(Mercator::Terrain & data,
                             PointSet & modifiedTerrain,
                             PointSet & createdTerrain,
                             unsigned int flags);

    virtual bool get(Atlas::Message::Element &) const;
    virtual void set(const Atlas::Message::Element &);
};

#endif // RULESETS_TERRAIN_PROPERTY_H
